@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.9.2"
+    return "0.9.4"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "11 November 2021"
+    return "01 December 2021"
